<?php
/**
 * COMMENTS v.1.0 December 2015
 * to see COMMENTS on CERTAIN ARTICLES.
 * 
 * support: sorting configured in menu items.
 * numbering on item, numbering on page, max item per page, max paging per page.
 */
 
// No direct access to this file
defined('_JEXEC') or die('Restricted access');

class CCauthModelStock_list extends JModelItem
{
	protected $messages;

/*************************  COMMON FUNCTIONS *****************************/

	public function sanitizeInput($input){
		$input = trim($input);
		$input = stripslashes($input);
		$input = htmlspecialchars($input);
		return $input;
		}
		

/********************  AUTHORITY CHECK FUNCTIONS *************************/


	public function getAuth() 
	{	
		$skey 	= $this->getSkey(); 
		$uscode = $this->getUscode(); 
		$priv_req = 'authall'; //required privilege
		$check = $this->getInstance('Home', 'CCauthModel')->home_check_priv($skey, $uscode, $priv_req); // this refer function in the home model.
		return $check;
	}

/*****************  GETTING THE DATA TO DETERMINE HOW THE PAGE LOOKS *******************/
	
	public function getSkey($id = 1) {		//authority check
		$jinput = JFACTORY::getApplication()->input;
		$result = $jinput->get('skey','','string'); //default page is empty.
		$result = $this->sanitizeInput($result);
		return $result;		
	}
	
	public function getUscode($id = 1) {		//authority check
		$jinput = JFACTORY::getApplication()->input;
		$result = $jinput->get('uscode','','string'); //default page is empty.
		$result = $this->sanitizeInput($result);
		return $result;		
	}
	
	public function getId() {		
		$jinput = JFACTORY::getApplication()->input;
		$result = $jinput->get('id','','string'); //default page is empty.
		$result = $this->sanitizeInput($result);
		return $result;		
	}
	
	public function getName(){
		$db = JFactory::getDbo();
		$query = $db->getQuery(true);	
		$query->select('enname');
		$query->from($db->quoteName('#__ccwarehousemaster','a'));
		$query->where($db->quoteName('a.published') . '  = ' . $db->quote('1'));
		$query->where($db->quoteName('a.status') . ' = ' . $db->quote('1'));
		$query->where($db->quoteName('a.enid') . ' = ' . $db->quote($this->getId()));
	
		$db->setQuery($query);

		$result = $db->loadResult();	
		return $result;			
	}
	
	
	/*****************  FUNCTIONS FOR LIST OF MESSAGES HELPERS *******************/

	public function getPage($id = 1) {		
		$jinput = JFACTORY::getApplication()->input;
		$page = $jinput->get('page',1,'int'); //default page is 1.
				
		//validation process
		$page = $this->sanitizeInput($page);
		$itemscount = $this->getItemscount();
		$itemsperpage = $this->getItemsperpage();
			
		// get from xml
		$maxpage = round(($itemscount / $itemsperpage) + 0.5,0,PHP_ROUND_HALF_DOWN);
		
		if($page < 1){$page = 1;}//default page is 1.
		if($page > $maxpage){$page = $maxpage;} //max is maxpage
		return $page;
	}

	
//get current maximum paging per screen.
	public function getMaxpaging($id = 1){
		// get from xml
		$app = JFactory::getApplication();
		$params = $app->getParams();
				
		$result = $params->get('maxpage', 10); //if not set, then 10 as default
		return $result;			
	}

//count number of messages / items matching criteria, so it can be calculated for paging.
	public function getItemscount($id = 1) {
		// This function is to count eligible items. Results are returned to get the max page.
		// Apply restrictions accordingly.
		// No need to apply ordering in the query
		
//		$months = $this->getMonth();

		$db = JFactory::getDbo();
		$query = $db->getQuery(true);

		// how to use
		/*
		$fields = array, example: $fields = array('a.*', 'b.username', 'b.name');
		$table1 and table2 = array, table and assigned variable, example $table = ('#__content', 'a');
		$conditions = [0] set the table and operator, [1] tested values, example $conditions = array('b.username', ' = 2');
		*/
		$query->select(array('a.*','b.name'));
		$query->from($db->quoteName('#__ccsales','a'));
		
		$query->join('INNER', $db->quoteName('#__cccust','b') . ' ON ' . $db->quoteName('a.cuid') . ' = ' . $db->quoteName('b.cuid'));
		
		$query->where($db->quoteName('a.published') . ' > ' . $db->quote('0'));
		
		if(isset($months)){
		//	$query->where($db->quoteName('a.samonth') . ' = ' . $db->quote($months) );
			}
		$query->order($db->quoteName('a.salesid'). ' ASC');
		
		$db->setQuery($query);

		// Load the results as a list of stdClass objects (see later for more options on retrieving data).
		//$results = $db->loadObjectList();
		$results = $db->loadColumn();
		return count($results);
		}
	
		
//get numbers of messages/items shown per page.
	public function getItemsperpage(){

		// get from xml if database is not set
		$app = JFactory::getApplication();
		$params = $app->getParams();
				
		$result = $params->get('maxitem',10); //if not set, 10 as default
		
		return $result;
		}

// now get the comments to be displayed, according to matching criteria.
	


	
	public function getOrdering($id = 1) {	
		$app = JFactory::getApplication();
		$params = $app->getParams();
		$order_default = $app->input->get('limit', $params->get('orderby_sec', 'inid'), 'uint');
		
		//new: override if set by user. dont forget to validate
		$jinput = JFACTORY::getApplication()->input;
		$order_type = $jinput->get('orderby',$order_default); //default get parameter

		$order_submit = $this->sanitizeInput($jinput->get('ordering_submit')); 
		if (isset($order_submit))
		{
		$order_type = $order_submit;
		}
		$validDataOrdering = ['id','rid','name','rname','date', 'rdate'];
		
		$order_type = $this->getInstance('Home', 'CCauthModel')->validateCompare($order_type, $validDataOrdering);
					
		return $order_type;
	}
		

	public function selectRow(){
		$db = JFactory::getDbo();
		$query = $db->getQuery(true);	
		//$months = $this->getMonth();
		$query->select(array('a.*'));
		//$query->select($db->quoteName('b.name'));
		$query->from($db->quoteName('#__ccsales','a'));
		$db->setQuery($query);
		// Load the results as a list of stdClass objects (see later for more options on retrieving data).
		$results = $db->loadObjectList();
		return $results;			
	}
	

	public function selectRows($select="*", $table="", $wheres = array(), $whereins = "", $wherefields="", $orders = array(), $table2="", $joint_type = " INNER", $joints1="", $joints2="")
	{
		//example usage in view : 	$a = JModelLegacy::getInstance('Prod_list', 'CCauthModel')->selectRows(array('id','usid'), '#__ccauth', array('status',1), 'usid', array('umar','ccayadi'));

		// example to access : echo $a[0]->passwrd

		$db = JFactory::getDbo();
		$query = $db->getQuery(true);
		
		$ins = "";
		foreach($wherefields as $in){
			$ins .= '"'.$in.'",';
		}
		$ins = chop($ins, ',' );
		
		$query->select($select);
		$query->from($db->quoteName($table));

		if($table2 !=""){
		$query->join($joint_type, $db->quoteName($table2) . ' ON ' . $db->quoteName($joints1) . ' = ' . $db->quoteName($joints2));
		}
		if(!empty($wheres)){
		$query->where($db->quoteName($wheres[0]) . ' = ' . $db->quote($wheres[1]));
		}
		if($whereins !=""){
			$query->where($db->quoteName($whereins) .' IN ( '.$ins.')');
		
		}
		if(!empty($orders)){
		$query->order($db->quoteName($orders[0]) . $orders[1]);
		}

		$db->setQuery($query);

		$results = $db->loadObjectList();
		return $results;
	}		
		

	public function getMenus($id = 1){
		$valid = $this->getAuth();//authority check
		$uscode = $this->getUscode(); 
		
		if($valid == 1)
		{
			$results = $this->getInstance('Home', 'CCauthModel')->home_get_menus($uscode);
		} else { 
			$results = array(); //return empty array when no menu found for the user.
		}
		return $results;
	}
	
	public function getFilterEntity(){
	}
	
	public function getFilterItem(){
	}
	
	public function getIncomingRequestAsk(){
		return $this->getPendingRequest(0, 1);
	}
	public function getIncomingRequestOffered(){
		return $this->getPendingRequest(0, 2);
	}	
	public function getIncomingCommit(){
		return $this->getPendingRequest(1);
	}
	public function getIncomingDeliver(){
		return $this->getPendingRequest(2);		
	}
	public function getIncomingConfirm(){
		return $this->getPendingRequest(3);		
	}
	
	public function getOutgoingRequestAsked(){
		return $this->getPendingRequestTo(0, 1);
	}	
	public function getOutgoingRequestOffer(){
		return $this->getPendingRequestTo(0, 2);
	}	
	public function getOutgoingCommit(){
		return $this->getPendingRequestTo(1);
	}
	public function getOutgoingDeliver(){
		return $this->getPendingRequestTo(2);
	}
	public function getOutgoingConfirm(){
		return $this->getPendingRequestTo(3);
	}
	public function getPendingRequest($status=0, $movtype=""){
		$id = $this->getID();
		
		$db = JFactory::getDbo();
		$query = $db->getQuery(true);	
		$query->select(array('id', 'startdate', 'duedate','movtype','reqnumber','entityto','entityfrom','itemcode','quantity','status'));
		$query->from($db->quoteName('#__ccinvemov','a'));
		
			//$query->join('INNER', $db->quoteName('#__ccsalesmaster','c') . ' ON ' . $db->quoteName('c.itemcode') . ' = ' . $db->quoteName('a.itemcode'));
			
		$query->where($db->quoteName('a.published') . ' > ' . $db->quote('0'));
		$query->where($db->quoteName('a.status') . ' = ' . $db->quote($status));
		$query->where($db->quoteName('a.entityto') . ' = ' . $db->quote($id));
		if($movtype!=""){
		$query->where($db->quoteName('a.movtype') . ' = ' . $db->quote($movtype));
		}
		$query->order(' a.itemcode ASC, a.startdate ASC');

		$db->setQuery($query);
		// Load the results as a list of stdClass objects (see later for more options on retrieving data).
		$results = $db->loadObjectList();
		
		return $results;
		}
	
	public function getPendingRequestTo($status=0, $movtype=""){
		
		$id = $this->getID();
		
		$db = JFactory::getDbo();
		$query = $db->getQuery(true);	
		$query->select(array('id', 'startdate', 'duedate','movtype','reqnumber','entityto','entityfrom','itemcode','quantity','status'));
		$query->from($db->quoteName('#__ccinvemov','a'));
		
			//$query->join('INNER', $db->quoteName('#__ccsalesmaster','c') . ' ON ' . $db->quoteName('c.itemcode') . ' = ' . $db->quoteName('a.itemcode'));
			
		$query->where($db->quoteName('a.published') . ' > ' . $db->quote('0'));
		$query->where($db->quoteName('a.status') . ' = ' . $db->quote($status));
		$query->where($db->quoteName('a.entityfrom') . ' = ' . $db->quote($id));
		if($movtype!=""){
		$query->where($db->quoteName('a.movtype') . ' = ' . $db->quote($movtype));
		}
		$query->order('a.itemcode ASC, a.startdate ASC ');

		$db->setQuery($query);
		// Load the results as a list of stdClass objects (see later for more options on retrieving data).
		$results = $db->loadObjectList();
		return $results;

	}
	
	public function getThingsWheres($select, $table, $where, $in){
	$db = JFactory::getDbo();
	$query = $db->getQuery(true);	
	$query->select($select);
	$query->from($db->quoteName($table));
	$max = count($where);
	if($max > 4){
		$query->where($db->quoteName($where[4]) . ' = ' . $db->quote($in[4]));
	}
	if($max > 3){
		$query->where($db->quoteName($where[3]) . ' = ' . $db->quote($in[3]));
	}	
	if($max > 2){
		$query->where($db->quoteName($where[2]) . ' = ' . $db->quote($in[2]));
	}	
	if($max > 1){
		$query->where($db->quoteName($where[1]) . ' = ' . $db->quote($in[1]));
	}	
	if($max > 0){
		$query->where($db->quoteName($where[0]) . ' = ' . $db->quote($in[0]));
	}
	$db->setQuery($query);
	// Load the results as a list of stdClass objects (see later for more options on retrieving data).
	$results = $db->loadObjectList();			
	
	return $results;
	}
	
	public function getStock()
		{
	//	$valid = $this->getAuth();//authority check
	
			// get from xml
			$jinput = JFACTORY::getApplication()->input;

		//	$page = $this->getPage();//get current page
	//		$skipitems = $itemsperpage * ($page - 1);
	
			$id = $this->getID();
			$skey 	= $this->getSkey(); 
			$uscode = $this->getUscode(); 
		//	$months = $this->getMonth();
			$filter_by_entity = $this->getFilterEntity();
			$filter_by_item = $this->getFilterItem();
			$sortby = $this->getOrdering();
			
			$db = JFactory::getDbo();
			$query = $db->getQuery(true);	
			$query->select(array('a.*','b.itemcode','b.name as itemname'));
			$query->from($db->quoteName('#__ccwarehouse','a'));
	//		$query->join('INNER', $db->quoteName('#__ccsalesmaster','b') . ' ON ' . $db->quoteName('a.itemcode') . ' = ' . $db->quoteName('b.id'));
			$query->join('INNER', $db->quoteName('#__ccinvemaster','b') . ' ON ' . $db->quoteName('a.itemcode') . ' = ' . $db->quoteName('b.itemcode'));
			
			$query->where($db->quoteName('a.published') . ' > ' . $db->quote('0'));
			$query->where($db->quoteName('a.enid') . ' = ' . $db->quote($id));

			if($filter_by_entity!=''){
			$query->where($db->quoteName('a.enid') . ' = ' . $db->quoteName($filter_by_entity));
			}
			if($filter_by_item!=''){
			$query->where($db->quoteName('a.itemcode') . ' = ' . $db->quoteName($filter_by_item));
			}
			
			if($sortby!=''){
			} else{
			$query->order('a.enid ASC, a.itemcode ASC');
			}
			
	//		$query->setLimit($itemsperpage,$skipitems);
			$db->setQuery($query);

			// Load the results as a list of stdClass objects (see later for more options on retrieving data).
			$results = $db->loadObjectList();			
			
	
			return $results;
	}
	
	
}